pub struct Function(/* private fields */);Expand description
A Deserializable javascript function, that can be stored and used later Must live as long as the runtime it was birthed from
Implementations
Sourceimpl Function
impl Function
Sourcepub fn into_v8(self) -> Global<Value>
pub fn into_v8(self) -> Global<Value>
Returns the underlying crate::deno_core::v8::Global
This is useful if you want to pass the value to a crate::deno_core::JsRuntime function directly
Sourcepub fn as_v8(&self) -> &Global<Value>
pub fn as_v8(&self) -> &Global<Value>
Returns a reference to the underlying crate::deno_core::v8::Global
This is useful if you want to pass the value to a crate::deno_core::JsRuntime function directly
Sourcepub fn try_from_v8<'a, H>(
scope: &mut HandleScope<'a>,
value: Global<H>,
) -> Result<Self, Error>
pub fn try_from_v8<'a, H>( scope: &mut HandleScope<'a>, value: Global<H>, ) -> Result<Self, Error>
Creates a new instance of this struct from a global value
Errors
Will return an error if the value is the wrong type
For Value, this check cannot fail
Sourcepub unsafe fn from_v8_unchecked(value: Global<Value>) -> Self
pub unsafe fn from_v8_unchecked(value: Global<Value>) -> Self
Creates a new instance of this struct from a global value Makes no attempt to check the type of the value This can result in a panic if the value is not of the correct type
Safety
This function is unsafe because it does not check the type of the value
If the value is not of the correct type, a panic will occur
It is recommended to use Self::try_from_v8 instead
Sourceimpl Function
impl Function
Sourcepub fn call<T>(
&self,
runtime: &mut Runtime,
module_context: Option<&ModuleHandle>,
args: &impl Serialize,
) -> Result<T, Error>where
T: DeserializeOwned,
pub fn call<T>(
&self,
runtime: &mut Runtime,
module_context: Option<&ModuleHandle>,
args: &impl Serialize,
) -> Result<T, Error>where
T: DeserializeOwned,
Calls this function. See crate::Runtime::call_stored_function
Blocks until:
- The event loop is resolved, and
- If the value is a promise, the promise is resolved
Errors
Will return an error if the function cannot be called, if the function returns an error Or if the function returns a value that cannot be deserialized into the given type
Sourcepub async fn call_async<T>(
&self,
runtime: &mut Runtime,
module_context: Option<&ModuleHandle>,
args: &impl Serialize,
) -> Result<T, Error>where
T: DeserializeOwned,
pub async fn call_async<T>(
&self,
runtime: &mut Runtime,
module_context: Option<&ModuleHandle>,
args: &impl Serialize,
) -> Result<T, Error>where
T: DeserializeOwned,
Calls this function. See crate::Runtime::call_stored_function_async
Returns a future that resolves when:
- The event loop is resolved, and
- If the value is a promise, the promise is resolved
Errors
Will return an error if the function cannot be called, if the function returns an error Or if the function returns a value that cannot be deserialized into the given type
Sourcepub fn call_immediate<T>(
&self,
runtime: &mut Runtime,
module_context: Option<&ModuleHandle>,
args: &impl Serialize,
) -> Result<T, Error>where
T: DeserializeOwned,
pub fn call_immediate<T>(
&self,
runtime: &mut Runtime,
module_context: Option<&ModuleHandle>,
args: &impl Serialize,
) -> Result<T, Error>where
T: DeserializeOwned,
Calls this function. See crate::Runtime::call_stored_function_immediate
Does not wait for the event loop to resolve, or attempt to resolve promises
Errors
Will return an error if the function cannot be called, if the function returns an error Or if the function returns a value that cannot be deserialized into the given type